# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-10-17 00:26
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='RequestProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('started_at', models.DateTimeField()),
                ('created_at', models.DateTimeField()),
                ('request_path', models.TextField(blank=True)),
                ('response_code', models.IntegerField()),
                ('time_real', models.FloatField()),
                ('time_user', models.FloatField()),
                ('time_sys', models.FloatField()),
                ('allocated_vm', models.IntegerField()),
                ('data', models.BinaryField(null=True)),
                ('request_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
